@@ -5,22 +5,25 @@ from django.template import loader, RequestContext, Template
 from django.views.decorators.gzip import gzip_page
 from django.conf import settings
 
-from tiote import forms, utils, views, sql
+from tiote import forms, sql, sa
+from tiote.utils import *
+from tiote.views import *
+
 
 @gzip_page
 def index(request):
-    utils.fns.set_ajax_key(request)
+    fns.set_ajax_key(request)
     request.session.set_expiry(getattr(settings, 'TT_SESSION_EXPIRY', 1800) )
     
     # redirect based on the return of check_login()
-    if not utils.fns.check_login(request):
+    if not fns.check_login(request):
         return HttpResponseRedirect('login/')
     
     # return empty template
     c = {}
-    template = utils.fns.skeleton('start')
+    template = fns.skeleton('start')
     context = RequestContext(request, {
-        }, [utils.fns.site_proc]
+        }, [fns.site_proc]
     )
     context.update(c)
     return HttpResponse(template.render(context))
@@ -28,9 +31,9 @@ def index(request):
 # ajax calls router
 @gzip_page
 def ajax(request):
-    conn_params = utils.fns.get_conn_params(request)
+    conn_params = fns.get_conn_params(request)
     # check if the session is still logged in
-    if not utils.fns.check_login(request):
+    if not fns.check_login(request):
         h = HttpResponse('')
         h.set_cookie('TT_SESSION_TIMEOUT', 'true')
         return h
@@ -38,11 +41,11 @@ def ajax(request):
     # check if its and XmlHttpRequest
     if not request.is_ajax():
         # return 500 error
-        return utils.fns.http_500('not an ajax request!')
+        return fns.http_500('not an ajax request!')
     
-    if not utils.fns.validateAjaxRequest(request):
+    if not fns.validateAjaxRequest(request):
         # might change this to send back the login page
-        return utils.fns.http_500('invalid ajax request!')
+        return fns.http_500('invalid ajax request!')
     # ajax request is okay
     
     
@@ -55,35 +58,35 @@ def ajax(request):
     if request.GET.get('q'):
         q = request.GET.get('q')
         if q == 'sidebar':
-            return utils.fns.generate_sidebar(request)
+            return htm.generate_sidebar(request)
         elif request.GET.get('type') == 'fn':
-            return HttpResponse(utils.db.fn_query(conn_params, q, utils.fns.qd(request.GET),
-                utils.fns.qd(request.POST)) )
+            return HttpResponse(qry.fn_query(conn_params, q, fns.qd(request.GET),
+                fns.qd(request.POST)) )
         elif request.GET.get('type') == 'repr':
-            return HttpResponse( utils.db.rpr_query(conn_params, q, utils.fns.qd(request.GET),
-                utils.fns.qd(request.POST)) )
+            return HttpResponse( qry.rpr_query(conn_params, q, fns.qd(request.GET),
+                fns.qd(request.POST)) )
         elif request.GET.get('type') == 'full':
-            return HttpResponse( utils.db.full_query(conn_params, q, utils.fns.qd(request.GET), utils.fns.qd(request.POST)) )
+            return HttpResponse( qry.full_query(conn_params, q, fns.qd(request.GET), fns.qd(request.POST)) )
         else:
-            return utils.fns.http_500('feature not yet implemented!')
+            return fns.http_500('feature not yet implemented!')
         
         
     if not request.GET.get('v', False) and not request.GET.get('sctn', False):
-        return utils.fns.http_500('not a complete ajax request!')
+        return fns.http_500('not a complete ajax request!')
     
     # call corresponding function as request.GET.get('view', False)
-    if request.GET.get('v', False) == 'query':
+    if request.GET.get('v', False) in ('query', 'q'):
         return query(request)
     if request.GET.get('sctn', False) == 'begin':
-        return begin(request, utils.fns.qd(request.GET).get('v', False))
-    if request.GET.get('sctn', False) == 'home':
-        return views.home.route(request)
+        return begin(request, fns.qd(request.GET).get('v', False))
+    if request.GET.get('sctn', False) == 'hm':
+        return home.route(request)
     elif request.GET.get('sctn', False) == 'db':
-        return views.db.route(request)
+        return db.route(request)
     elif request.GET.get('sctn', False) == 'tbl':
-        return views.tbl.route(request)
+        return tbl.route(request)
     else:
-        return utils.fns.http_500('request corresponses to no function!')
+        return fns.http_500('request corresponses to no function!')
    
 @gzip_page
 def login(request):
@@ -91,10 +94,10 @@ def login(request):
     redi = request.META['PATH_INFO'].replace('login/', '')
     
     # if the user is already logged in take him back to the home page
-    if utils.fns.check_login(request):
-        return HttpResponseRedirect(redi + '#sctn=home&v=home')
+    if fns.check_login(request):
+        return HttpResponseRedirect(redi + '#sctn=hm&v=hm')
     
-    # dialects' info
+    # dialects' info: used for generating info and error messages
     c['dialects'] = [
         {'dialect': 'PostgreSQL', 'dialect_package':'python-psycopg2'},
         {'dialect': 'MySQL', 'dialect_package':'python-mysqldb'}, 
@@ -116,7 +119,7 @@ def login(request):
         form = forms.LoginForm(choices=choices, data=request.POST)
         c['form'] = form
         if form.is_valid():
-            dict_cd = utils.db.do_login(request, form.cleaned_data)
+            dict_cd = qry.do_login(request, form.cleaned_data)
             if dict_cd['login'] == True: return HttpResponseRedirect(redi)
             else: c['errors'] = [ dict_cd['msg'] ] 
 
@@ -125,7 +128,7 @@ def login(request):
         c['form'] = form
     
     t = loader.get_template('tt_login.html')
-    context = RequestContext(request, {}, [utils.fns.site_proc])
+    context = RequestContext(request, {}, [fns.site_proc])
     context.update(c)
     h = HttpResponse(t.render(context))
     return h
@@ -136,9 +139,9 @@ def begin(request, page, **kwargs):
     if kwargs:
         if kwargs.has_key('errors'):
             c.update({'errors': kwargs['errors']})
-    t = utils.fns.skeleton(page)
+    t = fns.skeleton(page)
     context = RequestContext(request, {
-        }, [utils.fns.site_proc]
+        }, [fns.site_proc]
     )
     context.update(c)
     h =  HttpResponse(t.render(context))
@@ -151,13 +154,13 @@ def query(request):
 
     It provides a form for running and returning SQL queries.
     '''
-    conn_params = utils.fns.get_conn_params(request)
+    conn_params = fns.get_conn_params(request)
     if request.method == 'POST':
         f = forms.QueryForm(request.POST)
-        if f.is_valid():
+        if f.is_valid(): # form validation successful
             query_string = request.POST.get('query')
             if request.GET.get('db', False): conn_params['db'] = request.GET.get('db')
-            r = sql.full_query(conn_params, query_string)
+            r = sa.full_query(conn_params, query_string)
             # if query encountered an error
             if type(r) == str:
                 ret = '<div class="alert-message error block-message .span6">{0}</div>'.format(
@@ -167,7 +170,7 @@ def query(request):
             else:
                 ret = '<div class="undefined" style="margin-bottom:10px;">[Query return {0}]</div>'.format(
                     str( r['count'] ) + " rows" if r['count'] > 0 else "no rows")
-                results_table = utils.fns.HtmlTable(**r)
+                results_table = htm.HtmlTable(**r)
                 if results_table.has_body():
                     ret += results_table.to_element()
             h = HttpResponse(ret)
@@ -176,13 +179,13 @@ def query(request):
 
         else:
             ret = {'status': 'fail', 
-            'msg': utils.fns.render_template(request,"tt_form_errors.html",
+            'msg': fns.render_template(request,"tt_form_errors.html",
                 {'form': f}, is_file=True).replace('\n','')
             }
             return HttpResponse(unicode(ret))
         
     f = forms.QueryForm() 
-    return utils.fns.response_shortcut(request, 
+    return fns.response_shortcut(request, 
         extra_vars={'form':f,'sub':'Run query', 'small_form': True}, template='form')
     
     
\ No newline at end of file
